@@ -344,14 +344,14 @@ def generate_sku(allowed_data_types = [str]):
     asin_list = input_col_name_1
 
 
-    from get_other_row_data import get_other_row_data
+    from ArbMasterPy.get_other_row_data import get_other_row_data
     date_list=get_other_row_data(column_mappings, curr_attr="ASIN", new_attr="Order Date", 
     target_sheet=xw.apps.active.books.active.sheets.active,
     target_address=input_col_name_1_address)
     
 
     sku_list = []
-    from inventory_data import get_attribute
+    from ArbMasterPy.inventory_data import get_attribute
     asin_sku_dict = get_attribute('seller-sku') #Ethan
     import datetime
     select_name_and_click_ok_or_terminate("SKU column", keep_on_top=True, affirmative_response={"OK"})
